"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LbcForm = void 0;
const react_1 = require("@chakra-ui/react");
const yup_1 = require("@hookform/resolvers/yup");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const wallet_adapter_react_1 = require("@solana/wallet-adapter-react");
const web3_js_1 = require("@solana/web3.js");
const react_2 = require("@strata-foundation/react");
const router_1 = require("next/router");
const react_3 = __importDefault(require("react"));
const react_async_hook_1 = require("react-async-hook");
const react_hook_form_1 = require("react-hook-form");
const yup = __importStar(require("yup"));
const marketplaceSdkContext_1 = require("../../contexts/marketplaceSdkContext");
const routes_1 = require("../../utils/routes");
const FormControlWithError_1 = require("./FormControlWithError");
const MintSelect_1 = require("./MintSelect");
const Recipient_1 = require("./Recipient");
const TokenMetadataInputs_1 = require("./TokenMetadataInputs");
const validationSchema = yup.object({
    mint: yup.string().required(),
    image: yup.mixed(),
    name: yup.string().required().min(2),
    description: yup.string(),
    symbol: yup.string().min(2).max(10),
    authority: yup.string().required(),
    startPrice: yup.number().min(0).required(),
    minPrice: yup.number().min(0).required(),
    interval: yup.number().min(0).required(),
    decimals: yup.number().min(0).required(),
    mintCap: yup.number().min(1).required(),
    goLiveDate: yup.date().required()
});
function createLiquidityBootstrapper(marketplaceSdk, values) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const targetMintKeypair = web3_js_1.Keypair.generate();
        const authority = new web3_js_1.PublicKey(values.authority);
        const mint = new web3_js_1.PublicKey(values.mint);
        const uri = yield marketplaceSdk.tokenMetadataSdk.createArweaveMetadata({
            name: values.name,
            symbol: values.symbol,
            description: values.description,
            image: (_a = values.image) === null || _a === void 0 ? void 0 : _a.name,
            files: [values.image].filter(react_2.truthy),
            mint: targetMintKeypair.publicKey,
        });
        const { targetMint } = yield marketplaceSdk.createLiquidityBootstrapper({
            targetMintKeypair,
            authority,
            metadata: new mpl_token_metadata_1.DataV2({
                // Max name len 32
                name: values.name.substring(0, 32),
                symbol: values.symbol.substring(0, 10),
                uri,
                sellerFeeBasisPoints: 0,
                creators: null,
                collection: null,
                uses: null,
            }),
            baseMint: mint,
            startPrice: Number(values.startPrice),
            minPrice: Number(values.minPrice),
            interval: Number(values.interval),
            maxSupply: Number(values.mintCap),
            bondingArgs: {
                targetMintDecimals: Number(values.decimals),
                goLiveDate: values.goLiveDate
            },
        });
        return targetMint;
    });
}
const LbcForm = () => {
    const formProps = (0, react_hook_form_1.useForm)({
        resolver: (0, yup_1.yupResolver)(validationSchema),
    });
    const { register, handleSubmit, watch, setValue, formState: { errors, isSubmitting }, } = formProps;
    const { publicKey } = (0, wallet_adapter_react_1.useWallet)();
    const { info: tokenRef } = (0, react_2.usePrimaryClaimedTokenRef)(publicKey);
    const { awaitingApproval } = (0, react_2.useProvider)();
    const { execute, loading, error } = (0, react_async_hook_1.useAsyncCallback)(createLiquidityBootstrapper);
    const { marketplaceSdk } = (0, marketplaceSdkContext_1.useMarketplaceSdk)();
    const router = (0, router_1.useRouter)();
    const { authority, mint } = watch();
    const mintKey = (0, react_2.usePublicKey)(mint);
    const onSubmit = (values) => __awaiter(void 0, void 0, void 0, function* () {
        const mintKey = yield execute(marketplaceSdk, values);
        router.push((0, routes_1.route)(routes_1.routes.mintLbc, { mintKey: mintKey.toBase58() }));
    });
    const authorityRegister = register("authority");
    return (react_3.default.createElement(react_hook_form_1.FormProvider, Object.assign({}, formProps),
        react_3.default.createElement("form", { onSubmit: handleSubmit(onSubmit) },
            react_3.default.createElement(react_1.VStack, { spacing: 8 },
                react_3.default.createElement(TokenMetadataInputs_1.TokenMetadataInputs, null),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "symbol", help: "A less than 10 character symbol for the token being sold", label: "Symbol", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({}, register("symbol")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "mint", help: `The mint that should be used to buy this token, example ${spl_token_1.NATIVE_MINT.toBase58()} for SOL`, label: "Mint", errors: errors },
                    tokenRef && (react_3.default.createElement(react_1.Button, { variant: "link", onClick: () => setValue("mint", tokenRef.mint.toBase58()) }, "Use my Social Token")),
                    react_3.default.createElement(MintSelect_1.MintSelect, { value: watch("mint"), onChange: (s) => setValue("mint", s) })),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "authority", help: "The wallet that receives the bootstrapped liquidity", label: "Beneficiary", errors: errors },
                    publicKey && (react_3.default.createElement(react_1.Button, { variant: "link", onClick: () => setValue("authority", publicKey.toBase58()) }, "Set to My Wallet")),
                    react_3.default.createElement(Recipient_1.Recipient, { name: authorityRegister.name, value: authority, onChange: authorityRegister.onChange })),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "decimals", help: "The number of decimals on this mint", label: "Mint Decimals", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.000000000001 }, register("decimals")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "startPrice", help: "The starting price for this token. You should set this a little above the expected price of the token. Prices will fall to the fair price. Note that if there's enough demand, they can also increae from this price", label: "Staring Price", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.000000000001 }, register("startPrice")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "minPrice", help: "The minimum possible price for this token, if nobody buys during the bootstrapping interval.", label: "Minimum Price", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.000000000001 }, register("minPrice")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "interval", help: "The time in seconds that it will take to go from startPrice to minPrice", label: "Interval", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.000000000001 }, register("interval")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "mintCap", help: "The number of tokens to mint. Note that, depending on the above parameters this liqudity bootstrapping may not sell out", label: "Number of Tokens", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.000000000001 }, register("mintCap")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "goLiveDate", help: "The time this LBC will go live, in your browser's local timezone", label: "Launch Date", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "datetime-local" }, register("goLiveDate")))),
                error && react_3.default.createElement(react_1.Alert, { status: "error" }, error.toString()),
                react_3.default.createElement(react_1.Button, { type: "submit", alignSelf: "flex-end", colorScheme: "primary", isLoading: isSubmitting || loading, loadingText: awaitingApproval ? "Awaiting Approval" : "Loading" }, "Create LBC")))));
};
exports.LbcForm = LbcForm;
//# sourceMappingURL=LbcForm.js.map