"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SaleForm = void 0;
const react_1 = require("@chakra-ui/react");
const yup_1 = require("@hookform/resolvers/yup");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const wallet_adapter_react_1 = require("@solana/wallet-adapter-react");
const web3_js_1 = require("@solana/web3.js");
const react_2 = require("@strata-foundation/react");
const marketplaceSdkContext_1 = require("../..//contexts/marketplaceSdkContext");
const router_1 = require("next/router");
const react_3 = __importDefault(require("react"));
const react_async_hook_1 = require("react-async-hook");
const react_hook_form_1 = require("react-hook-form");
const bs_1 = require("react-icons/bs");
const routes_1 = require("../../utils/routes");
const yup = __importStar(require("yup"));
const FormControlWithError_1 = require("./FormControlWithError");
const MintSelect_1 = require("./MintSelect");
const TokenMetadataInputs_1 = require("./TokenMetadataInputs");
const validationSchema = yup.object({
    mint: yup.string().required(),
    image: yup.mixed(),
    name: yup.string().required().min(2),
    description: yup.string().required().min(2),
    quantity: yup.number().required().min(1).integer(),
    price: yup.number().required().min(0),
    curve: yup.string()
});
function createMarket(marketplaceSdk, values) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const mint = new web3_js_1.PublicKey(values.mint);
        const targetMintKeypair = web3_js_1.Keypair.generate();
        const uri = yield marketplaceSdk.tokenMetadataSdk.createArweaveMetadata({
            name: values.name,
            symbol: "",
            description: values.description,
            image: (_a = values.image) === null || _a === void 0 ? void 0 : _a.name,
            files: [values.image].filter(react_2.truthy),
            mint: targetMintKeypair.publicKey,
            attributes: [
                {
                    trait_type: "is_strata_sale",
                    display_type: "Strata Sale",
                    value: "true",
                },
            ],
        });
        yield marketplaceSdk.createMarketItem({
            targetMintKeypair,
            metadata: new mpl_token_metadata_1.DataV2({
                name: values.name,
                symbol: "",
                uri,
                sellerFeeBasisPoints: 0,
                creators: null,
                collection: null,
                uses: null,
            }),
            quantity: values.quantity,
            price: values.price,
            baseMint: mint,
            bondingArgs: {
                curve: values.curve ? new web3_js_1.PublicKey(values.curve) : undefined
            }
        });
        return targetMintKeypair.publicKey;
    });
}
const SaleForm = () => {
    const formProps = (0, react_hook_form_1.useForm)({
        resolver: (0, yup_1.yupResolver)(validationSchema)
    });
    const { register, handleSubmit, setValue, formState: { errors, isSubmitting }, watch } = formProps;
    const { publicKey } = (0, wallet_adapter_react_1.useWallet)();
    const { info: tokenRef } = (0, react_2.usePrimaryClaimedTokenRef)(publicKey);
    const { awaitingApproval } = (0, react_2.useProvider)();
    const { execute, loading, error } = (0, react_async_hook_1.useAsyncCallback)(createMarket);
    const { marketplaceSdk } = (0, marketplaceSdkContext_1.useMarketplaceSdk)();
    const router = (0, router_1.useRouter)();
    const { isOpen, onToggle } = (0, react_1.useDisclosure)();
    const onSubmit = (values) => __awaiter(void 0, void 0, void 0, function* () {
        const mintKey = yield execute(marketplaceSdk, values);
        router.push((0, routes_1.route)(routes_1.routes.sale, {
            mintKey: mintKey.toBase58()
        }));
    });
    return (react_3.default.createElement(react_hook_form_1.FormProvider, Object.assign({}, formProps),
        react_3.default.createElement("form", { onSubmit: handleSubmit(onSubmit) },
            react_3.default.createElement(react_1.VStack, { spacing: 8 },
                react_3.default.createElement(TokenMetadataInputs_1.TokenMetadataInputs, null),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "quantity", help: "The quantity to stop selling at", label: "Quantity", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 1, step: 1 }, register("quantity")))),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "mint", help: `The mint that should be used to purchase this, example ${spl_token_1.NATIVE_MINT.toBase58()}`, label: "Mint", errors: errors },
                    tokenRef && (react_3.default.createElement(react_1.Button, { variant: "link", onClick: () => setValue("mint", tokenRef.mint.toBase58()) }, "Use my Social Token")),
                    react_3.default.createElement(MintSelect_1.MintSelect, { value: watch("mint"), onChange: (s) => setValue("mint", s) }),
                    " "),
                react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "price", help: "The price of the item", label: "Price", errors: errors },
                    react_3.default.createElement(react_1.Input, Object.assign({ type: "number", min: 0, step: 0.0000000001 }, register("price")))),
                react_3.default.createElement(react_1.Flex, { alignItems: "flex-start", direction: "column", w: "full" },
                    react_3.default.createElement(react_1.Button, { textAlign: "left", rightIcon: react_3.default.createElement(react_1.Icon, { as: bs_1.BsChevronDown }), variant: "link", onClick: onToggle }, "Advanced Settings"),
                    react_3.default.createElement(react_1.Box, { w: "full" },
                        react_3.default.createElement(react_1.Collapse, { in: isOpen, animateOpacity: true },
                            react_3.default.createElement(FormControlWithError_1.FormControlWithError, { id: "curve", help: "The pricing curve to use for this item", label: "Curve", errors: errors },
                                react_3.default.createElement(react_1.Input, Object.assign({}, register("curve"))))))),
                error && (react_3.default.createElement(react_1.Alert, { status: "error" },
                    react_3.default.createElement(react_1.Alert, { status: "error" }, error.toString()))),
                react_3.default.createElement(react_1.Button, { type: "submit", alignSelf: "flex-end", colorScheme: "primary", isLoading: isSubmitting || loading, loadingText: awaitingApproval ? "Awaiting Approval" : "Loading" }, "Create Sale")))));
};
exports.SaleForm = SaleForm;
//# sourceMappingURL=SaleForm.js.map