"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BondingPlot = void 0;
const react_1 = require("@chakra-ui/react");
const react_2 = require("@strata-foundation/react");
const moment_1 = __importDefault(require("moment"));
const react_3 = __importStar(require("react"));
const bi_1 = require("react-icons/bi");
const recharts_1 = require("recharts");
const useSampledTransactions_1 = require("../../hooks/useSampledTransactions");
const numberWithCommas_1 = require("../../utils/numberWithCommas");
const BondingPlot = ({ tokenBondingKey }) => {
    const { transactions, error, loadingInitial, loadingMore, fetchMore } = (0, useSampledTransactions_1.useSampledTransactions)({
        address: tokenBondingKey,
        numTransactions: 40
    });
    const { handleErrors } = (0, react_2.useErrorHandler)();
    handleErrors(error);
    const { info: tokenBonding, loading: loadingBonding } = (0, react_2.useTokenBonding)(tokenBondingKey);
    const labelColor = (0, react_1.useColorModeValue)("black", "white");
    const data = (0, react_3.useMemo)(() => {
        return tokenBonding ? transactions.map(transaction => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
            const reserveIdx = transaction.transaction.message.accountKeys
                .map((k) => k.toBase58())
                .indexOf(tokenBonding.baseStorage.toBase58());
            const preReserves = (_c = (_b = (_a = transaction.meta) === null || _a === void 0 ? void 0 : _a.preTokenBalances) === null || _b === void 0 ? void 0 : _b.find((b) => b.accountIndex == reserveIdx &&
                b.mint == tokenBonding.baseMint.toBase58())) === null || _c === void 0 ? void 0 : _c.uiTokenAmount.uiAmount;
            const postReserves = (_f = (_e = (_d = transaction.meta) === null || _d === void 0 ? void 0 : _d.postTokenBalances) === null || _e === void 0 ? void 0 : _e.find((b) => b.accountIndex == reserveIdx && b.mint == tokenBonding.baseMint.toBase58())) === null || _f === void 0 ? void 0 : _f.uiTokenAmount.uiAmount;
            const reserveChange = (postReserves || 0) - (preReserves || 0);
            const preToken = (_k = (_j = (_h = (_g = transaction.meta) === null || _g === void 0 ? void 0 : _g.preTokenBalances) === null || _h === void 0 ? void 0 : _h.filter((b) => b.mint == tokenBonding.targetMint.toBase58())) === null || _j === void 0 ? void 0 : _j.map((v) => v.uiTokenAmount.uiAmount)) === null || _k === void 0 ? void 0 : _k.reduce((v1, v2) => (v1 || 0) + (v2 || 0), 0);
            const postToken = (_p = (_o = (_m = (_l = transaction.meta) === null || _l === void 0 ? void 0 : _l.postTokenBalances) === null || _m === void 0 ? void 0 : _m.filter((b) => b.mint == tokenBonding.targetMint.toBase58())) === null || _o === void 0 ? void 0 : _o.map((v) => v.uiTokenAmount.uiAmount)) === null || _p === void 0 ? void 0 : _p.reduce((v1, v2) => (v1 || 0) + (v2 || 0), 0);
            const tokenChange = (postToken || 0) - (preToken || 0);
            return {
                price: reserveChange / tokenChange,
                time: (transaction.blockTime || 0) * 1000
            };
        }).filter(d => d.price) : [];
    }, [transactions, tokenBonding]);
    const icoColor = (0, react_1.useColorModeValue)("black", "white");
    if (loadingBonding || loadingInitial) {
        return (react_3.default.createElement(react_1.Center, null,
            react_3.default.createElement(react_2.Spinner, null)));
    }
    return (react_3.default.createElement(react_1.VStack, { spacing: 4, w: "full", align: "left" },
        react_3.default.createElement(react_1.HStack, { spacing: 0 },
            react_3.default.createElement(react_1.Text, { fontSize: "14px", fontWeight: "700" }, "Price History"),
            react_3.default.createElement(react_1.IconButton, { "aria-label": "Fetch More", onClick: () => fetchMore(10), isLoading: loadingMore, color: icoColor, variant: "link", icon: react_3.default.createElement(react_1.Icon, { h: "24px", w: "24px", mb: "-2px", as: bi_1.BiRefresh }) })),
        react_3.default.createElement(react_1.Box, { w: "full", h: "136px" },
            react_3.default.createElement(recharts_1.ResponsiveContainer, { height: "100%" },
                react_3.default.createElement(recharts_1.LineChart, { data: data },
                    react_3.default.createElement(recharts_1.CartesianGrid, { stroke: "rgba(229, 229, 229, 0.3)" }),
                    react_3.default.createElement(recharts_1.XAxis, { tickCount: 5, interval: 0, dataKey: "time", domain: ["auto", "auto"], name: "Time", tickFormatter: (unixTime) => (0, moment_1.default)(unixTime).format("LT"), type: "number" }),
                    react_3.default.createElement(recharts_1.YAxis, { tickFormatter: (num) => (0, numberWithCommas_1.numberWithCommas)(num, 2), tickCount: 3, domain: ["auto", "auto"], tickLine: false, type: "number", orientation: "right", stroke: labelColor, width: 40, axisLine: false }),
                    react_3.default.createElement(recharts_1.Line, { dot: false, type: "monotone", dataKey: "price", stroke: "#81fff0" }))))));
};
exports.BondingPlot = BondingPlot;
//# sourceMappingURL=BondingPlot.js.map