"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSampledTransactions = void 0;
const wallet_adapter_react_1 = require("@solana/wallet-adapter-react");
const react_1 = require("@strata-foundation/react");
const react_2 = require("react");
function sampleSize(arr, num) {
    const len = arr.length;
    const step = Math.max(Math.floor(len / num), 1);
    const includeLast = step * num == len;
    const sampled = [];
    for (let i = 0; i < len; i += step) {
        sampled.push(arr[i]);
    }
    return [...sampled, includeLast ? arr[-1] : undefined].filter(react_1.truthy);
}
function getSignatures(connection, address, until, lastSignature) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!connection || !address) {
            return [];
        }
        const signatures = yield connection.getSignaturesForAddress(address, {
            before: lastSignature,
            limit: 1000
        });
        const withinTime = signatures.filter(sig => (sig.blockTime || 0) > (((until === null || until === void 0 ? void 0 : until.valueOf()) || 0) / 1000));
        if (withinTime.length == 1000) {
            return [
                ...withinTime,
                ...(yield getSignatures(connection, address, until, signatures[signatures.length - 1].signature)),
            ];
        }
        return withinTime;
    });
}
function sampleTransactions(connection, signatures, numTransactions) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!connection) {
            return [];
        }
        const sampled = sampleSize(signatures, numTransactions).sort((a, b) => (a.blockTime || 0) - (b.blockTime || 0));
        return (yield Promise.all(sampled.map(s => connection.getTransaction(s.signature)))).filter(react_1.truthy);
    });
}
const useSampledTransactions = ({ numTransactions, until, address }) => {
    const { connection } = (0, wallet_adapter_react_1.useConnection)();
    const [loadingInitial, setLoadingInitial] = (0, react_2.useState)(true);
    const [loadingMore, setLoadingMore] = (0, react_2.useState)(false);
    const [error, setError] = (0, react_2.useState)();
    const [transactions, setTransactions] = (0, react_2.useState)([]);
    const addrStr = (0, react_2.useMemo)(() => address === null || address === void 0 ? void 0 : address.toBase58(), [address]);
    (0, react_2.useEffect)(() => {
        (() => __awaiter(void 0, void 0, void 0, function* () {
            setLoadingInitial(true);
            try {
                const signatures = yield getSignatures(connection, address, until, undefined);
                setTransactions(yield sampleTransactions(connection, signatures, numTransactions));
            }
            catch (e) {
                setError(e);
            }
            finally {
                setLoadingInitial(false);
            }
        }))();
    }, [connection, addrStr, until, setTransactions, numTransactions]);
    const fetchMore = () => __awaiter(void 0, void 0, void 0, function* () {
        setLoadingMore(true);
        try {
            const lastTx = transactions[transactions.length - 1];
            const lastBlockTime = lastTx && lastTx.blockTime;
            let lastDate = until;
            if (lastBlockTime) {
                const date = new Date(0);
                date.setUTCSeconds(lastBlockTime);
                lastDate = date;
            }
            const signatures = yield getSignatures(connection, address, lastDate, undefined);
            const newTxns = yield sampleTransactions(connection, signatures, numTransactions);
            setTransactions((txns) => [...txns, ...newTxns]);
        }
        catch (e) {
            setError(e);
        }
        finally {
            setLoadingMore(false);
        }
    });
    return {
        transactions,
        error,
        loadingInitial,
        loadingMore,
        fetchMore
    };
};
exports.useSampledTransactions = useSampledTransactions;
//# sourceMappingURL=useSampledTransactions.js.map